Struct RoomState
#[non_exhaustive]pub struct RoomState {
pub members_omitted: bool,
pub auth_chain: Vec<Box<RawValue>>,
pub state: Vec<Box<RawValue>>,
pub event: Option<Box<RawValue>>,
pub servers_in_room: Option<Vec<String>>,
}api only.Expand description
Full state of the room.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.members_omitted: boolWhether m.room.member events have been omitted from state.
Defaults to false.
auth_chain: Vec<Box<RawValue>>The full set of authorization events that make up the state of the room, and their authorization events, recursively.
If the request had omit_members set to true, then any events that are returned in
state may be omitted from auth_chain, whether or not membership events are omitted
from state.
state: Vec<Box<RawValue>>The room state.
If the request had omit_members set to true, events of type m.room.member may be
omitted from the response to reduce the size of the response. If this is done,
members_omitted must be set to true.
event: Option<Box<RawValue>>The signed copy of the membership event sent to other servers by the resident server, including the resident server’s signature.
Required if the room version supports restricted join rules.
servers_in_room: Option<Vec<String>>A list of the servers active in the room (ie, those with joined members) before the join.
Required if members_omitted is set to true.
Implementations