#[non_exhaustive]pub struct Response {
pub signatures: Signatures<OwnedServerName, ServerSigningKeyVersion>,
}Available on crate feature
api and (crate features federation-api-c or federation-api-s) only.Expand description
Response type for the sign_event endpoint.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signatures: Signatures<OwnedServerName, ServerSigningKeyVersion>A map containing the Policy Server’s signature of the event.
This signature is to be added to the event before sending or processing the event further.
ed25519:policy_server is always used for Ed25519 signatures.
Implementations
Sourceimpl Response
impl Response
Sourcepub const POLICY_SERVER_ED25519_SIGNING_KEY_ID: &'static str = "ed25519:policy_server"
pub const POLICY_SERVER_ED25519_SIGNING_KEY_ID: &'static str = "ed25519:policy_server"
The signing key ID that must be used by the Policy Server for the ed25519 signature.
Sourcepub fn new(server_name: OwnedServerName, ed25519_signature: String) -> Response
pub fn new(server_name: OwnedServerName, ed25519_signature: String) -> Response
Creates a new Response with the given Policy Server name and event signature.
Sourcepub fn ed25519_signature(&self, server_name: &ServerName) -> Option<&str>
pub fn ed25519_signature(&self, server_name: &ServerName) -> Option<&str>
Get the signature of the event for the given Policy Server name, if any.